@@ -21,6 +21,6 @@ tsconfigsmoke.pl - Configure the Perl5 core tester suite (L<Test::Smoke>).
 
 =head1 SEE ALSO
 
-L<lib/configsmoke.pod> or L<README2.md>
+L<lib/configsmoke.pod> or L<HOWTO.md>
 
 =cut
