@@ -2,13 +2,15 @@ package Test::Smoke::Syncer::FTP;
 use warnings;
 use strict;
 
+our $VERSION = '0.029';
+
 use base 'Test::Smoke::Syncer::Base';
+use Cwd;
 
 =head1 Test::Smoke::Syncer::FTP
 
-This handles syncing by getting the source-tree from ActiveState's APC
-repository. It uses the C<Test::Smoke::FTPClient> that implements a
-mirror function.
+This handles syncing by getting the source-tree from a FTP server.
+It uses the C<Test::Smoke::FTPClient> that implements a mirror function.
 
 =cut
 
@@ -18,11 +20,10 @@ use File::Spec::Functions;
 
 Known args for this class:
 
-    * ftphost (public.activestate.com)
+    * ftphost (ftp.example.com)
     * ftpusr  (anonymous)
-    * ftppwd  (smokers@perl.org)
-    * ftpsdir (/pub/apc/perl-????)
-    * ftpcdir (/pub/apc/perl-????-diffs)
+    * ftppwd (?)
+    * ftpsdir (/)
     * ftype (undef|binary|ascii)
 
     * ddir
@@ -34,7 +35,6 @@ Known args for this class:
 
 This does the actual syncing:
 
-    * Check {ftpcdir} for the latest changenumber
     * Mirror
 
 =cut
@@ -45,7 +45,7 @@ sub sync {
     $self->pre_sync;
     require Test::Smoke::FTPClient;
 
-    my $fc = Test::Smoke::FTPClient->new( $self->{ftphost}, {
+    my $fc = Test::Smoke::FTPClient->new( $self->{ftphost}, $self->{ftpport}, {
         v       => $self->{v},
         passive => $self->{ftppassive},
         fuser   => $self->{ftpusr},
@@ -58,43 +58,21 @@ sub sync {
     $fc->mirror( @{ $self }{qw( ftpsdir ddir )}, 1 ) or return;
 
     $self->{client} = $fc;
+    $self->{v} = $fc->{v};
+
+    my $cwd = cwd();
+    chdir $self->{ddir} or croak("Cannot chdir($self->{ddir}): $!");
+
+    $self->make_dot_patch();
+
+    my $plevel = $self->check_dot_patch;
+
+    chdir $cwd or croak("Cannot chdir($cwd): $!");
 
-    my $plevel = $self->create_dot_patch;
     $self->post_sync;
     return $plevel;
 }
 
-=head2 $syncer->create_dot_patch
-
-This needs to go to the *-diffs directory on APC and find the patch
-whith the highest number, that should be our current patchlevel.
-
-=cut
-
-sub create_dot_patch {
-    my $self = shift;
-    my $ftp = $self->{client}->{client};
-
-    $ftp->cwd( $self->{ftpcdir} );
-    my $plevel = (sort { $b <=> $a } map {
-        s/\.gz$//; $_
-    } grep /\d+\.gz/ => $ftp->ls)[0];
-
-    my $dotpatch = catfile( $self->{ddir}, '.patch' );
-    local *DOTPATH;
-    if ( open DOTPATCH, "> $dotpatch" ) {
-        print DOTPATCH $plevel;
-        close DOTPATCH or do {
-            require Carp;
-            Carp::carp( "Error writing '$dotpatch': $!" );
-        };
-    } else {
-        require Carp;
-        Carp::carp( "Error creating '$dotpatch': $!" );
-    }
-    return $plevel;
-}
-
 1;
 
 =head1 COPYRIGHT
